==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebColumnSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnSelectionEventArgsDetailDescription } from "./WebColumnSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnSelectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnSelectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnSelectionEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnSelectionEventArgsDetailDescriptionMetadata.c(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnSelectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("OldSelection", "Array:string");
            a.item("NewSelection", "Array:string");
            a.item("Added", "Array:string");
            a.item("Removed", "Array:string");
        }
        static d(a) {
            WebColumnSelectionEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebColumnSelectionEventArgsDetail", () => new WebColumnSelectionEventArgsDetailDescription());
            a.ac("WebColumnSelectionEventArgsDetail", WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnSelectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnSelectionEventArgsDetailDescriptionMetadata, 'WebColumnSelectionEventArgsDetailDescriptionMetadata');
    WebColumnSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebColumnSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnSelectionEventArgsDetailDescription } from "./WebColumnSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnSelectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnSelectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnSelectionEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnSelectionEventArgsDetailDescriptionMetadata.c(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnSelectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnSelectionEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("OldSelection", "Array:string");
            a.item("NewSelection", "Array:string");
            a.item("Added", "Array:string");
            a.item("Removed", "Array:string");
            a.item("Cancel", "Boolean");
            a.item("Owner", "Unknown");
        }
        static d(a) {
            WebColumnSelectionEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebColumnSelectionEventArgsDetail", () => new WebColumnSelectionEventArgsDetailDescription());
            a.ad("WebColumnSelectionEventArgsDetail", WebColumnSelectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnSelectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnSelectionEventArgsDetailDescriptionMetadata, 'WebColumnSelectionEventArgsDetailDescriptionMetadata');
    WebColumnSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnSelectionEventArgsDetailDescriptionMetadata;
})();
